summaryrefslogtreecommitdiffstats
path: root/src/store
diff options
context:
space:
mode:
authorJohn Molakvoæ <skjnldsv@users.noreply.github.com>2018-12-19 09:50:56 +0100
committerGitHub <noreply@github.com>2018-12-19 09:50:56 +0100
commita66e3fd69be92eb02ffdf5a9b85803d80eede0ed (patch)
tree4c71814fd06cbb82547ede97503e2b4327e98e7b /src/store
parent19663029ac4d6a8d6efe96aaab163431654f7a0e (diff)
parent14f9b4c57e7cdaf1dc7b75361796b4db3203a129 (diff)
Merge pull request #778 from nextcloud/groups-new-contact-fix
Fix groups addition and new contact instertion into groups
Diffstat (limited to 'src/store')
-rw-r--r--src/store/contacts.js3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/store/contacts.js b/src/store/contacts.js
index 8aaa2079..8cb8f496 100644
--- a/src/store/contacts.js
+++ b/src/store/contacts.js
@@ -261,7 +261,7 @@ const actions = {
},
/**
* Add a contact to the list and to the associated addressbook
*
* @param {Object} context the store mutations
* @param {Contact} contact the contact to delete
@@ -269,6 +269,7 @@ const actions = {
async addContact(context, contact) {
await context.commit('addContact', contact)
await context.commit('addContactToAddressbook', contact)
+ await context.commit('extractGroupsFromContacts', [contact])
},
/**
@@ -261,7 +261,7 @@ const actions = {
},
/**
- * Add a contact to the list and to the associated addressbook
+ * Add a contact to the list, the associated addressbook and to the groups
*
* @param {Object} context the store mutations